import numpy as np
import cv2 as cv
import importlib

Colors = importlib.import_module("greyBlobDetector", "Colors").Colors
GreyBlobDetector = importlib.import_module("greyBlobDetector", "GreyBlobDetector").GreyBlobDetector

class ContourEdgeDetector:
    # HSV value for RED
    RED_THRESHOLD = 8
    # HSV value for BLUE
    BLUE_THRESHOLD = 230

    def __init__(self):
        pass

    def detect_color(self, image, gaussian_blur = False):
        # gaussian blur is basically there to reduce the noise
        if gaussian_blur:
            # apply gaussian blur here
            image = cv.GaussianBlur(image,(5,5),0)
        gd = GreyBlobDetector()
        contours = gd.detect_color(image)

        if len(contours) == 0:
            return Colors.GREY
        else:
            # we know that its either blue or red
            # use the edges as a mask
            mask = np.zeros(image.shape[0], image.shape[1])
            cv.drawContours(mask, contours, -1, (255), 1)
            # applies the mask to image
            image[mask != 0] = (0,0,0)
            # transform this to hsv
            hsv = cv.cvtColor(image, cv.COLOR_BGR2HSV)
            # note : 0,0,0 will still be 0,0,0
            colors = hsv[:,:,0]
            average = colors.sum() / (colors != 0).sum()

            if abs(average - ContourEdgeDetector.RED_THRESHOLD) \
                < abs(average - ContourEdgeDetector.BLUE_THRESHOLD):
                return Colors.RED
            else:
                return Colors.BLUE





